/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.exports;

import org.jfree.chart.plot.XYPlot;

/**
 * Implementors of this class can be used to tweak some very application specific behaviour within the charts.<br/>
 * Implementations should not have a state, because they are instantiated only once.
 *
 * @author Gernot Belger
 */
public interface ChartExtender {

    /**
     * Called before {@link DiagramGenerator#autoZoom(org.jfree.chart.plot.XYPlot)} is called, allows to tweak auto zoom
     * behavior.
     */
    void beforeAutoZoom(DiagramGenerator generator);

    /**
     * Called after {@link DiagramGenerator#autoZoom(org.jfree.chart.plot.XYPlot)} was called, allows to tweak auto zoom
     * behavior.
     */
    void afterAutoZoom(DiagramGenerator generator);

    /**
     * Called after the complete chart is generated.
     *
     * @param plot
     */
    void afterGenerateChart(DiagramGenerator generator, XYPlot plot);
}